@@ -4,7 +4,7 @@ use warnings;
 package OS::Package;
 
 # ABSTRACT: OS Package Management System
-our $VERSION = '0.2.6'; # VERSION
+our $VERSION = '0.2.7'; # VERSION
 
 use Moo;
 use Path::Tiny;
@@ -66,7 +66,7 @@ OS::Package - OS Package Management System
 
 =head1 VERSION
 
-version 0.2.6
+version 0.2.7
 
 =head1 AUTHOR
 
@@ -74,7 +74,7 @@ James F Wilkus <jfwilkus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by James F Wilkus.
+This software is Copyright (c) 2015 by James F Wilkus.
 
 This is free software, licensed under:
 
@@ -82,6 +82,26 @@ This is free software, licensed under:
 
 =head1 CHANGES
 
+=head2 Version 0.2.7 (2015-06-23)
+
+=over 4
+
+=item *
+
+Add repository directory option
+
+=back
+
+=head2 Version 0.2.6 (2014-09-29)
+
+=over 4
+
+=item *
+
+Fix log entry
+
+=back
+
 =head2 Version 0.2.5 (2014-09-28)
 
 =over 4
